# UI/UX Feedback

**ID:** Feedback-20260221-174334
**URL:** http://127.0.0.1:5858/
**Date:** 2026-02-21 17:46:34

## Selected Elements

- `{'selector': 'div.deliverable-card-header', 'parents': ['div.workflow-panel-body', 'div.deliverables-area', 'div.deliverables-grid', 'div.deliverable-card.folder-type']}`

## Feedback

the folder in the deliverable, looks like the style is not correct, you can reference the idea deliverable, which having background for the icon(use diference color since they are different type), then folder name and it's path need to be in different line. btw, not matter which deliverable, when display let's hide x-ipe-docs/ since all the docs should under it

## Screenshot

![Screenshot](./page-screenshot.png)
